/*************************************************************************************
 *
 * Nema 17 motor
 *
 *************************************************************************************
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHOR OR COPYRIGHT
 * HOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * IT IS NOT PERMITTED TO MODIFY THIS COMMENT BLOCK.
 *
 * (c)2016, Claude "Tryphon" Theroux, Montreal, Quebec, Canada
 * http://www.ctheroux.com/
 *
 ************************************************************************************/
 
 include <Common.scad>

// Motor case height and width
nema17CaseSize = 42.20;

// Motor mount hole distance.
nema17MotorMountingHoleDistance = 31;

// Rotor shaft recess diameter
nema17RotorShaftRecessDiameter = 22;

// Rotor shaft recess extra diameter
nema17RotorShaftRecessExtraDiameter = 3;

////////////////////////////////////////////////////////////////////////////////
// Nothing below shall be modified

// Rotor recess radius
nema17RotorShaftRecessRadius = (nema17RotorShaftRecessDiameter + nema17RotorShaftRecessExtraDiameter) / 2;

////////////////////////////////////////////////////////////////////////////////
// Motor mounting holes.
//
// motorPlateTickness is the motor plate tickness
module Nema17MotorMountHoles(motorPlateTickness) {
  union() {
   translate([0, 0, -0.5]) 
      cylinder(h=motorPlateTickness*2, r=nema17RotorShaftRecessRadius);
    translate([-nema17MotorMountingHoleDistance / 2, -nema17MotorMountingHoleDistance / 2, -0.5]) M3ScrewHole();
    translate([-nema17MotorMountingHoleDistance / 2, nema17MotorMountingHoleDistance / 2, -0.5]) M3ScrewHole();
    translate([nema17MotorMountingHoleDistance / 2, -nema17MotorMountingHoleDistance / 2, -0.5]) M3ScrewHole();
    translate([nema17MotorMountingHoleDistance / 2, nema17MotorMountingHoleDistance / 2, -0.5]) M3ScrewHole();
  }
}

module Nema17MotorBasePlate(motorPlateTickness, extraHeight) {
  difference() {
      translate([-nema17CaseSize / 2, -nema17CaseSize / 2, 0]) cube([nema17CaseSize + extraHeight, nema17CaseSize,   motorPlateTickness]);
    Nema17MotorMountHoles(motorPlateTickness);
  }
}

